@@ -37,8 +37,7 @@
 #include "cellrenderer.h"
 
 void
-cb_preferences_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+cb_preferences_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	ProcData *procdata = user_data;
 	
@@ -63,7 +62,6 @@ cb_end_process (GtkMenuItem *menuitem, gpointer data)
 		procdialog_create_kill_dialog (procdata, SIGTERM);
 	else
 		kill_process (procdata, SIGTERM);
-	
 }
 
 void
@@ -160,7 +158,6 @@ cb_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 	
 }
 
-
 void
 cb_app_exit (GtkObject *object, gpointer user_data)
 {
@@ -205,47 +202,23 @@ cb_close_simple_dialog (GnomeDialog *dialog, gpointer data)
 
 }
 #endif
-void
-cb_all_process_menu_clicked 		(GtkWidget	*widget,
-					 gpointer	data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	
-	g_return_if_fail (data);
-	procdata->config.whose_process = ALL_PROCESSES;
-	gconf_client_set_int (client, "/apps/procman/view_as", 
-			      procdata->config.whose_process, NULL);
-	
-}
-
 
 void
-cb_my_process_menu_clicked		(GtkWidget	*widget,
-					 gpointer	data)
+cb_proc_combo_changed (GtkComboBox *combo, gpointer data)
 {
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	
+	ProcData *procdata;
+	GConfClient *client;
+
 	g_return_if_fail (data);
-	procdata->config.whose_process = MY_PROCESSES;
+
+	procdata = data;
+	client = procdata->client;
+
+	procdata->config.whose_process = gtk_combo_box_get_active (combo);
 	gconf_client_set_int (client, "/apps/procman/view_as", 
 			      procdata->config.whose_process, NULL);
 }
 
-void
-cb_running_process_menu_clicked		(GtkWidget	*widget,
-					 gpointer	data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	
-	g_return_if_fail (data);
-	procdata->config.whose_process = RUNNING_PROCESSES;
-	gconf_client_set_int (client, "/apps/procman/view_as", 
-			      procdata->config.whose_process, NULL);
-}				
-
 void
 popup_menu_renice (GtkMenuItem *menuitem, gpointer data)
 {
@@ -344,7 +317,6 @@ cb_info_button_pressed			(GtkButton	*button,
 	ProcData *procdata = user_data;
 	
 	toggle_infoview (procdata);
-		
 }	
 
 void		
@@ -360,7 +332,6 @@ cb_search (GtkEditable *editable, gpointer data)
 	g_free (text);
 }
 
-
 void		
 cb_cpu_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
 		      guint a, gpointer data)
@@ -447,35 +418,38 @@ cb_row_selected (GtkTreeSelection *selection, gpointer data)
 	
 }
 
+void
+cb_tree_row_activated (GtkTreeView *view,
+		       GtkTreePath *path, 
+		       GtkTreeViewColumn *column,
+		       gpointer data)
+{
+	ProcData *procdata = data;
+
+	toggle_infoview (procdata);
+}
+
 gboolean
-cb_tree_button_pressed (GtkWidget *widget, GdkEventButton *event, 
+cb_tree_button_pressed (GtkWidget *widget,
+		        GdkEventButton *event, 
 			gpointer data)
 {
-        ProcData *procdata = data;
+	ProcData *procdata = data;
 
-	if (event->type == GDK_2BUTTON_PRESS) 
-		toggle_infoview (procdata);
-	else
+	if (event->button == 3 && event->type == GDK_BUTTON_PRESS)
         	do_popup_menu (procdata, event);
 
         return FALSE;
-
 }
 
-gint
-cb_tree_key_press (GtkWidget *widget, GdkEventKey *event, gpointer data)
+gboolean
+cb_tree_popup_menu (GtkWidget *widget, gpointer data)
 {
 	ProcData *procdata = data;
-		
-	switch (event->keyval) {
-	case GDK_Return:
-	case GDK_space:
-		toggle_infoview (procdata);
-		break;
-	}
-		
-	return FALSE;
-		
+
+	do_popup_menu (procdata, NULL);
+
+	return TRUE;
 }
 
 void		
@@ -554,7 +528,6 @@ compare_disks (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpoint
 		g_free (old_name);
 			
 		return FALSE;
-		
 	}
 	else {
 		old_iter = gtk_tree_iter_copy (iter);
@@ -563,7 +536,6 @@ compare_disks (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpoint
 	
 	g_free (old_name);
 	return FALSE;
-	
 }
 
 static GdkPixbuf*
@@ -618,7 +590,7 @@ add_new_disks (gpointer key, gpointer value, gpointer data)
 	GdkPixbuf *pixbuf = NULL;
 	GnomeIconTheme *icontheme;
 	icontheme  = gnome_icon_theme_new();
-	
+
 	glibtop_get_fsusage (&usage, entry->mountdir);
 	
 	/* Hmm, usage.blocks == 0 seems to get rid of /proc and all
@@ -640,7 +612,6 @@ add_new_disks (gpointer key, gpointer value, gpointer data)
 		text[2] = g_strdup (entry->type);
 		text[3] = get_size_string (btotal);
 		text[4] = get_size_string (bused);
-		text[5] = get_size_string (bfree);
 		
 		gtk_tree_store_insert (GTK_TREE_STORE (model), &row, NULL, 0); 
 		gtk_tree_store_set (GTK_TREE_STORE (model), &row,
@@ -659,12 +630,13 @@ add_new_disks (gpointer key, gpointer value, gpointer data)
 		g_free (text[2]);
 		g_free (text[3]);
 		g_free (text[4]);
-		g_free (text[5]);
+		
 		if (pixbuf)
 			g_object_unref (pixbuf);
+			
+		g_object_unref (icontheme);
 	}
-	
-	g_object_unref (G_OBJECT (icontheme));
+
 }
 
 gint
@@ -715,4 +687,3 @@ cb_timeout (gpointer data)
 	return TRUE;
 }
 
-
